import { AuthError } from '@supabase/supabase-js';
import { AUTH_CONSTANTS } from '@/lib/config/constants';

export class AuthenticationError extends Error {
  constructor(
    public readonly message: string,
    public readonly status: number = 500,
    public readonly originalError?: Error
  ) {
    super(message);
    this.name = 'AuthenticationError';
  }
}

export function handleAuthError(error: AuthError): AuthenticationError {
  const message = getErrorMessage(error);
  return new AuthenticationError(message, error.status || 500, error);
}

function getErrorMessage(error: AuthError): string {
  switch (error.message) {
    case 'Invalid login credentials':
      return AUTH_CONSTANTS.ERROR_MESSAGES.INVALID_CREDENTIALS;
    case 'Email not confirmed':
      return AUTH_CONSTANTS.ERROR_MESSAGES.EMAIL_NOT_CONFIRMED;
    case 'Email already registered':
      return AUTH_CONSTANTS.ERROR_MESSAGES.EMAIL_IN_USE;
    default:
      return error.message || AUTH_CONSTANTS.ERROR_MESSAGES.DEFAULT;
  }
}